@@ -5,7 +5,7 @@ use rcublas_sys::{
     cublasStatus_t,
 };
 
-use tensorgraph_sys::device::cuda::{Cuda, SharedStream};
+use tensorgraph_sys::device::cuda::{Cuda, CudaUnified, SharedStream};
 
 use super::{BLASContext, GEMM};
 
@@ -76,9 +76,8 @@ impl SharedCublasContext {
     }
 }
 
-impl<'a> BLASContext for &'a SharedCublasContext {
-    type Device = Cuda;
-}
+impl<'a> BLASContext<Cuda> for &'a SharedCublasContext {}
+impl<'a> BLASContext<CudaUnified> for &'a SharedCublasContext {}
 
 #[derive(Debug, Clone, Copy)]
 pub(crate) enum CublasError {
